@@ -2,65 +2,53 @@ use strict;
 use warnings;
 
 package Footprintless;
-$Footprintless::VERSION = '1.01';
+$Footprintless::VERSION = '1.02';
 # ABSTRACT: A utility for managing systems with minimal installs
 # PODNAME: Footprintless
 
 use Carp;
 use Config::Entities;
-use Footprintless::Util;
+use Footprintless::Util qw(factory);
 use Log::Any;
 
+our $AUTOLOAD;
+
 my $logger = Log::Any->get_logger();
 
 sub new {
     return bless( {}, shift )->_init(@_);
 }
 
+sub AUTOLOAD {
+    my ( $self, @args ) = @_;
+    my $method = $AUTOLOAD;
+    $method =~ s/.*:://;
+    $self->{factory}->$method(@args);
+}
+
 sub agent {
-    my ($self) = @_;
-    unless ( $self->{agent} ) {
-        $self->{agent} = Footprintless::Util::agent();
-    }
-    return $self->{agent};
+    my ( $self, @args ) = @_;
+    $self->{factory}->agent(@args);
 }
 
 sub command_options_factory {
-    my ($self) = @_;
-    unless ( $self->{command_options_factory} ) {
-        require Footprintless::CommandOptionsFactory;
-        $self->{command_options_factory} =
-            Footprintless::CommandOptionsFactory->new( localhost => $self->localhost() );
-    }
-    return $self->{command_factory};
+    my ( $self, @args ) = @_;
+    $self->{factory}->command_options_factory(@args);
 }
 
 sub command_runner {
-    my ($self) = @_;
-    unless ( $self->{command_runner} ) {
-        require Footprintless::Util;
-        $self->{command_runner} = Footprintless::Util::default_command_runner();
-    }
-    return $self->{command_runner};
+    my ( $self, @args ) = @_;
+    $self->{factory}->command_runner(@args);
 }
 
 sub deployment {
-    my ( $self, $coordinate, %options ) = @_;
-
-    require Footprintless::Deployment;
-    return Footprintless::Deployment->new(
-        $self->{entities}, $coordinate,
-        command_options_factory => $options{command_options_factory}
-            || $self->command_options_factory(),
-        command_runner   => $options{command_runner}   || $self->command_runner(),
-        localhost        => $options{localhost}        || $self->localhost(),
-        resource_manager => $options{resource_manager} || $self->resource_manager()
-    );
+    my ( $self, @args ) = @_;
+    $self->{factory}->deployment(@args);
 }
 
 sub entities {
-    my ($self) = @_;
-    return $self->{entities};
+    my ( $self, @args ) = @_;
+    $self->{factory}->entities(@args);
 }
 
 sub _init {
@@ -68,143 +56,106 @@ sub _init {
 
     $logger->debug('creating new Footprintless');
 
-    if ( $options{entities} ) {
-        if ( ref( $options{entities} ) eq 'HASH' ) {
-            $self->{entities} = Config::Entities->new( { entity => $options{entities} } );
-        }
-        elsif ( $options{entities}->isa('Config::Entities') ) {
-            $self->{entities} = $options{entities};
-        }
-        else {
-            croak('illegal entities, must be hashref, or Config::Entities');
-        }
+    if ( $options{factory} ) {
+        $self->{factory} = $options{factory};
     }
     else {
-        my $fpl_home;
-        if ( $options{fpl_home} ) {
-            $fpl_home = $options{fpl_home};
-        }
-        elsif ( $ENV{FPL_HOME} ) {
-            $fpl_home = $ENV{FPL_HOME};
-        }
-        else {
-            $fpl_home = File::Spec->catdir( $ENV{HOME}, '.footprintless' );
-        }
-
-        my @config_dirs = ();
-        if ( $options{config_dirs} ) {
-            @config_dirs =
-                ref( $options{config_dirs} ) eq 'ARRAY'
-                ? @{ $options{config_dirs} }
-                : ( $options{config_dirs} );
-        }
-        elsif ( $ENV{FPL_CONFIG_DIRS} ) {
-            @config_dirs = _split_dirs( $ENV{FPL_CONFIG_DIRS} );
-        }
-        else {
-            my $default = File::Spec->catdir( $fpl_home, 'config' );
-            if ( -d $default ) {
-                @config_dirs = ($default);
+        my $entities;
+        if ( $options{entities} ) {
+            if ( ref( $options{entities} ) eq 'HASH' ) {
+                $entities = Config::Entities->new( { entity => $options{entities} } );
+            }
+            elsif ( $options{entities}->isa('Config::Entities') ) {
+                $entities = $options{entities};
+            }
+            else {
+                croak('illegal entities, must be hashref, or Config::Entities');
             }
         }
-
-        my @config_options = ();
-        if ( $options{config_properties} ) {
-            push( @config_options, properties_file => $options{config_properties} );
-        }
-        elsif ( $ENV{FPL_CONFIG_PROPS} ) {
-            my @properties = _split_dirs( $ENV{FPL_CONFIG_PROPS} );
-            push( @config_options, properties_file => \@properties );
-        }
         else {
-            my $default = File::Spec->catdir( $fpl_home, 'properties.pl' );
-            if ( -f $default ) {
-                push( @config_options, properties_file => $default );
+            my $fpl_home;
+            if ( $options{fpl_home} ) {
+                $fpl_home = $options{fpl_home};
             }
+            elsif ( $ENV{FPL_HOME} ) {
+                $fpl_home = $ENV{FPL_HOME};
+            }
+            else {
+                $fpl_home = File::Spec->catdir( $ENV{HOME}, '.footprintless' );
+            }
+
+            my @config_dirs = ();
+            if ( $options{config_dirs} ) {
+                @config_dirs =
+                    ref( $options{config_dirs} ) eq 'ARRAY'
+                    ? @{ $options{config_dirs} }
+                    : ( $options{config_dirs} );
+            }
+            elsif ( $ENV{FPL_CONFIG_DIRS} ) {
+                @config_dirs = _split_dirs( $ENV{FPL_CONFIG_DIRS} );
+            }
+            else {
+                my $default = File::Spec->catdir( $fpl_home, 'config' );
+                if ( -d $default ) {
+                    @config_dirs = ($default);
+                }
+            }
+
+            my @config_options = ();
+            if ( $options{config_properties} ) {
+                push( @config_options, properties_file => $options{config_properties} );
+            }
+            elsif ( $ENV{FPL_CONFIG_PROPS} ) {
+                my @properties = _split_dirs( $ENV{FPL_CONFIG_PROPS} );
+                push( @config_options, properties_file => \@properties );
+            }
+            else {
+                my $default = File::Spec->catdir( $fpl_home, 'properties.pl' );
+                if ( -f $default ) {
+                    push( @config_options, properties_file => $default );
+                }
+            }
+
+            $logger->tracef(
+                "constructing entities with\n\tconfig_dirs: %s\n\tconfig_options: %s)",
+                \@config_dirs, {@config_options} );
+            $entities = Config::Entities->new( @config_dirs, {@config_options} );
         }
 
-        $logger->tracef( "constructing entities with\n\tconfig_dirs: %s\n\tconfig_options: %s)",
-            \@config_dirs, {@config_options} );
-        $self->{entities} = Config::Entities->new( @config_dirs, {@config_options} );
+        $self->{factory} = factory($entities);
     }
 
-    $self->{command_runner}          = $options{command_runner};
-    $self->{localhost}               = $options{localhost};
-    $self->{command_options_factory} = $options{command_options_factory};
-
     return $self;
 }
 
 sub localhost {
-    my ($self) = @_;
-    unless ( $self->{localhost} ) {
-        require Footprintless::Localhost;
-        $self->{localhost} = Footprintless::Localhost->new()->load_all();
-    }
-    return $self->{localhost};
+    my ( $self, @args ) = @_;
+    $self->{factory}->localhost(@args);
 }
 
 sub log {
-    my ( $self, $coordinate, %options ) = @_;
+    my ( $self, @args ) = @_;
+    $self->{factory}->log(@args);
+}
 
-    require Footprintless::Log;
-    return Footprintless::Log->new(
-        $self->{entities}, $coordinate,
-        command_options_factory => $options{command_options_factory}
-            || $self->command_options_factory(),
-        command_runner => $options{command_runner} || $self->command_runner(),
-        localhost      => $options{localhost}      || $self->localhost()
-    );
+sub plugins {
+    my ($self) = @_;
+    $self->{factory}->plugins();
 }
 
 sub overlay {
-    my ( $self, $coordinate, %options ) = @_;
-
-    require Footprintless::Overlay;
-    return Footprintless::Overlay->new(
-        $self->{entities}, $coordinate,
-        command_options_factory => $options{command_options_factory}
-            || $self->command_options_factory(),
-        command_runner   => $options{command_runner}   || $self->command_runner(),
-        localhost        => $options{localhost}        || $self->localhost(),
-        resource_manager => $options{resource_manager} || $self->resource_manager()
-    );
+    my ( $self, @args ) = @_;
+    $self->{factory}->overlay(@args);
 }
 
 sub resource_manager {
-    my ($self) = @_;
-    unless ( $self->{resource_manager} ) {
-        require Footprintless::ResourceManager;
-        my @providers = ();
-        my $agent     = $self->agent();
-        if ( require Maven::Agent ) {
-            require Footprintless::Resource::MavenProvider;
-            push(
-                @providers,
-                Footprintless::Resource::MavenProvider->new(
-                    Maven::Agent->new( agent => $agent )
-                )
-            );
-        }
-        require Footprintless::Resource::UrlProvider;
-        $self->{resource_manager} =
-            Footprintless::ResourceManager->new( @providers,
-            Footprintless::Resource::UrlProvider->new($agent) );
-    }
-    return $self->{resource_manager};
+    my ( $self, @args ) = @_;
+    $self->{factory}->resource_manager(@args);
 }
 
 sub service {
-    my ( $self, $coordinate, %options ) = @_;
-
-    require Footprintless::Service;
-    return Footprintless::Service->new(
-        $self->{entities}, $coordinate,
-        command_options_factory => $options{command_options_factory}
-            || $self->command_options_factory(),
-        command_runner => $options{command_runner} || $self->command_runner(),
-        localhost      => $options{localhost}      || $self->localhost()
-    );
+    my ( $self, @args ) = @_;
+    $self->{factory}->service(@args);
 }
 
 sub _split_dirs {
@@ -233,7 +184,7 @@ Footprintless - A utility for managing systems with minimal installs
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 SYNOPSIS
 
@@ -374,17 +325,6 @@ Creates a new Footprintless factory.  Available options are:
 
 =over 4
 
-=item entities
-
-If supplied, C<entities> will serve as the configuration for this instance.
-All other configuration sources will be ignored.  Must be either a hashref, 
-or an instance of L<Config::Entities>.
-
-=item fpl_home
-
-The root folder for footprintless configuration.  Defaults to the
-C<$FPL_HOME> environment variable if set, C<~/.footprintless> if not.
-
 =item config_dirs
 
 The root folder(s) for configuration entities.  Defaults to the 
@@ -404,21 +344,32 @@ the C<$FPL_CONFIG_PROPS> environment variable, and you need more than one
 directory, use a C<;> to delimit on windows, or a C<:> to delimit on *nix 
 (same as the C<$PATH> variable).
 
+=item command_options_factory
+
+Sets the C<command_options_factory> for this instance.  Must be an instance
+or subclass of C<Footprintless::CommandOptionsFactory>.
+
 =item command_runner
 
 Sets the C<command_runner> for this instance.  Must be an a subclass of
 C<Footprintless::CommandRunner>.
 
+=item entities
+
+If supplied, C<entities> will serve as the configuration for this instance.
+All other configuration sources will be ignored.  Must be either a hashref, 
+or an instance of L<Config::Entities>.
+
+=item fpl_home
+
+The root folder for footprintless configuration.  Defaults to the
+C<$FPL_HOME> environment variable if set, C<~/.footprintless> if not.
+
 =item localhost
 
 Sets the C<localhost> resolver for this instance.  Must be an instance
 or subclass of C<Footprintless::Localhost>.
 
-=item command_options_factory
-
-Sets the C<command_options_factory> for this instance.  Must be an instance
-or subclass of C<Footprintless::CommandOptionsFactory>.
-
 =back
 
 =head1 METHODS
@@ -530,9 +481,13 @@ this footprintless instance.
 
 =back
 
+=head2 plugins()
+
+Returns the registered plugins for this instance.
+
 =head2 resource_manager()
 
-Returns the L<resource_manager|Footprintless::ResourcManager> used by 
+Returns the L<resource_manager|Footprintless::ResourceManager> used by 
 this instance.
 
 =head2 service($coordinate, %options)
