@@ -2,12 +2,15 @@ use strict;
 use warnings;
 
 package Footprintless::App::Command::deployment;
-$Footprintless::App::Command::deployment::VERSION = '1.01';
+$Footprintless::App::Command::deployment::VERSION = '1.02';
 # ABSTRACT: Performs an action on a deployment.
 # PODNAME: Footprintless::App::Command::deployment
 
 use Carp;
 use Footprintless::App -command;
+use Footprintless::Util qw(
+    exit_due_to
+);
 use Log::Any;
 use Template::Overlay;
 use Template::Resolver;
@@ -28,20 +31,28 @@ sub execute {
         $self->_configure_logging( $opts->{log} );
     }
 
-    if ( $self->{action} eq 'clean' ) {
-        $logger->info('Performing clean...');
-        $self->{deployment}->clean();
-    }
-    elsif ( $self->{action} eq 'deploy' ) {
-        if ( $opts->{clean} ) {
+    eval {
+        if ( $self->{action} eq 'clean' ) {
             $logger->info('Performing clean...');
             $self->{deployment}->clean();
         }
-        $logger->info('Performing deploy...');
-        $self->{deployment}->deploy();
-    }
-    else {
-        croak("whoops, validation is broken, fix it");
+        elsif ( $self->{action} eq 'deploy' ) {
+            if ( $opts->{clean} ) {
+                $logger->info('Performing clean...');
+                $self->{deployment}->clean();
+            }
+            $logger->info('Performing deploy...');
+            $self->{deployment}->deploy();
+        }
+        else {
+            $self->usage_error("unsupported action [$self->{action}]");
+        }
+    };
+    if ($@) {
+        if ( ref($@) && $@->isa('Footprintless::InvalidEntityException') ) {
+            $self->usage_error($@);
+        }
+        exit_due_to( $@, 1 );
     }
 
     $logger->info('Done...');
@@ -69,8 +80,6 @@ sub validate_args {
     $self->usage_error("invalid coordinate [$coordinate]: $@") if ($@);
 
     $self->{action} = $action || 'deploy';
-    $self->usage_error("invalid action [$action], must be one of clean, deploy")
-        unless ( $self->{action} =~ /^clean|deploy$/ );
 }
 
 1;
@@ -85,7 +94,7 @@ Footprintless::App::Command::deployment - Performs an action on a deployment.
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 SYNOPSIS
 
