@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::App::Command::overlay;
-$Footprintless::App::Command::overlay::VERSION = '1.01';
+$Footprintless::App::Command::overlay::VERSION = '1.02';
 # ABSTRACT: Performs an action on an overlay.
 # PODNAME: Footprintless::App::Command::overlay
 
@@ -52,7 +52,7 @@ sub opt_spec {
 }
 
 sub usage_desc {
-    return "fpl %o [COORDINATE] [ACTION]";
+    return "fpl overlay [COORDINATE] [ACTION] %o";
 }
 
 sub validate_args {
@@ -82,7 +82,7 @@ Footprintless::App::Command::overlay - Performs an action on an overlay.
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 SYNOPSIS
 
@@ -97,8 +97,8 @@ Performs actions on an overlay.  The available actions are:
 
     clean        removes all files/folders handled by this overlay
     initialize   clean, then combine the base files and the processed template
-                 files, then deploy
-    update       process the template files, then deploy
+                 files
+    update       process the template files
 
 If no action is specified, C<update> is implied.  For detailed configuration 
 see L<Footprintless::Overlay>. 
