@@ -2,8 +2,9 @@ use strict;
 use warnings;
 
 package Footprintless::App::Command::service;
-$Footprintless::App::Command::service::VERSION = '1.01';
+$Footprintless::App::Command::service::VERSION = '1.02';
 use Footprintless::App -command;
+use Footprintless::Util qw(exit_due_to);
 use Log::Any;
 
 my $logger = Log::Any->get_logger();
@@ -26,8 +27,14 @@ sub execute {
         $self->_configure_logging( $opts->{log} );
     }
 
-    $logger->debugf( 'executing %s for %s', $opts->{execute}, $coordinate );
-    $self->{service}->execute($action);
+    $logger->debugf( 'executing %s for %s', $action, $coordinate );
+    eval { $self->{service}->execute($action); };
+    if ($@) {
+        if ( ref($@) && $@->isa('Footprintless::InvalidEntityException') ) {
+            $self->usage_error($@);
+        }
+        exit_due_to( $@, 1 );
+    }
 }
 
 sub opt_spec {
@@ -35,20 +42,26 @@ sub opt_spec {
 }
 
 sub usage_desc {
-    return "fpl %o [COORDINATE] [ACTION]";
+    return "fpl service [COORDINATE] [ACTION] %o";
 }
 
 sub validate_args {
     my ( $self, $opt, $args ) = @_;
     my ( $coordinate, $action ) = @$args;
 
-    $self->usage_error("coordinate is required") unless @$args;
+    $self->usage_error("coordinate is required") unless ($coordinate);
+    $self->usage_error("action is required")     unless ($action);
 
     my $footprintless = $self->app()->footprintless();
     eval { $self->{service} = $self->app()->footprintless()->service($coordinate); };
-    $self->usage_error("invalid coordinate [$coordinate]: $@") if ($@);
-
-    $self->usage_error("invalid action") unless ($action);
+    if ($@) {
+        if ( ref($@) && $@->isa('Footprintless::InvalidEntityException') ) {
+            $self->usage_error($@);
+        }
+        else {
+            $self->usage_error("invalid coordinate [$coordinate]: $@");
+        }
+    }
 }
 
 1;
@@ -63,14 +76,14 @@ Footprintless::App::Command::service - Performs an action on a service.
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 SYNOPSIS
 
-  fpl service project.environment.component.service kill
-  fpl service project.environment.component.service start
-  fpl service project.environment.component.service status
-  fpl service project.environment.component.service stop
+    fpl service foo.prod.web.service kill
+    fpl service foo.dev.app.service start
+    fpl service bar.qa.db.service status
+    fpl service baz.beta.support.service stop
 
 =head1 DESCRIPTION
 
