@@ -2,12 +2,12 @@ use strict;
 use warnings;
 
 package Footprintless::CommandRunner;
-$Footprintless::CommandRunner::VERSION = '1.01';
+$Footprintless::CommandRunner::VERSION = '1.02';
 # ABSTRACT: A contract for an command runner
 # PODNAME: Footprintless::CommandRunner
 
 use Carp;
-use Footprintless::CommandRunner::Exception;
+use Footprintless::CommandRunner::ExecutionException;
 use Log::Any;
 
 my $logger = Log::Any->get_logger();
@@ -68,7 +68,7 @@ sub run_or_die {
     my ( $self, $command, @runner_options ) = @_;
     my $exit_code = $self->run( $command, @runner_options );
     if ($exit_code) {
-        die(Footprintless::CommandRunner::Exception->new(
+        die(Footprintless::CommandRunner::ExecutionException->new(
                 $command,                      $exit_code,
                 $self->{last_call}{exception}, $self->{last_call}{stderr}
             )
@@ -89,7 +89,7 @@ Footprintless::CommandRunner - A contract for an command runner
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 DESCRIPTION
 
@@ -164,7 +164,8 @@ A handle to use as C<STDOUT> for the command.
 =head2 run_or_die($command, %runner_options)
 
 Calls L<run|/"run($command, @runner_options)"> and will die with an
-L<Footprintless::CommandRunner::Exception> if the exit code is non-zero.
+L<Footprintless::CommandRunner::ExecutionException> if the exit code is 
+non-zero.
 
 =head1 AUTHOR
 
@@ -197,7 +198,7 @@ L<Footprintless::CommandOptionsFactory|Footprintless::CommandOptionsFactory>
 
 =item *
 
-L<Footprintless::CommandRunner::Exception|Footprintless::CommandRunner::Exception>
+L<Footprintless::CommandRunner::ExecutionException|Footprintless::CommandRunner::ExecutionException>
 
 =item *
 
