@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Log;
-$Footprintless::Log::VERSION = '1.01';
+$Footprintless::Log::VERSION = '1.02';
 # ABSTRACT: A log manager
 # PODNAME: Footprintless::Log
 
@@ -13,6 +13,10 @@ use Footprintless::Command qw(
 );
 use Footprintless::CommandOptionsFactory;
 use Footprintless::Localhost;
+use Footprintless::Util qw(
+    dumper
+    invalid_entity
+);
 use Log::Any;
 
 my $logger = Log::Any->get_logger();
@@ -21,26 +25,37 @@ sub new {
     return bless( {}, shift )->_init(@_);
 }
 
+sub _action_args {
+    my ($args) = @_;
+    return '' unless ($args);
+
+    my $ref = ref($args);
+    return "$args " unless ($ref);
+
+    croak("unsupported ref type [$ref] for action options")
+        unless ( $ref eq 'ARRAY' );
+
+    return scalar(@$args)
+        ? join( ' ', @$args, '' )
+        : '';
+}
+
 sub cat {
     my ( $self, %options ) = @_;
-    my $log_file = $self->{spec};
 
-    my $action_options =
-        scalar( $options{options} )
-        ? join( ' ', @{ $options{options} }, '' )
-        : '';
+    my $action_args = _action_args( $options{args} );
 
     return $self->{command_runner}
-        ->run_or_die( command( "cat $action_options$log_file", $self->{command_options} ) );
+        ->run_or_die( command( "cat $action_args$self->{log_file}", $self->{command_options} ),
+        $self->_runner_options( $options{runner_options} ) );
 }
 
 sub follow {
     my ( $self, %options ) = @_;
-    my $log_file = $self->{spec};
 
     eval {
         $self->{command_runner}->run_or_die(
-            tail_command( $log_file, follow => 1, $self->{command_options} ),
+            tail_command( $self->{log_file}, follow => 1, $self->{command_options} ),
             $self->_runner_options( $options{runner_options}, $options{until} )
         );
     };
@@ -52,51 +67,57 @@ sub follow {
 
 sub grep {
     my ( $self, %options ) = @_;
-    my $log_file = $self->{spec};
 
-    my $action_options =
-        scalar( $options{options} )
-        ? join( ' ', @{ $options{options} }, '' )
-        : '';
+    my $action_args = _action_args( $options{args} );
 
     return $self->{command_runner}
-        ->run_or_die( command( "grep $action_options$log_file", $self->{command_options} ) );
+        ->run_or_die( command( "grep $action_args$self->{log_file}", $self->{command_options} ),
+        $self->_runner_options( $options{runner_options} ) );
 }
 
 sub head {
     my ( $self, %options ) = @_;
-    my $log_file = $self->{spec};
 
-    my $action_options =
-        scalar( $options{options} )
-        ? join( ' ', @{ $options{options} }, '' )
-        : '';
+    my $action_args = _action_args( $options{args} );
 
     return $self->{command_runner}
-        ->run_or_die( command( "head $action_options$log_file", $self->{command_options} ) );
+        ->run_or_die( command( "head $action_args$self->{log_file}", $self->{command_options} ),
+        $self->_runner_options( $options{runner_options} ) );
 }
 
 sub _init {
-    my ( $self, $entity, $coordinate, %options ) = @_;
-    $logger->tracef( "entity=[%s]\ncoordinate=[%s]\noptions=[%s]",
-        $entity, $coordinate, \%options );
+    my ( $self, $factory, $coordinate, %options ) = @_;
+    $logger->tracef( "coordinate=[%s]\noptions=[%s]", $coordinate, \%options );
 
-    $self->{entity} = $entity;
-    $self->{spec}   = $entity->get_entity($coordinate);
-    if ( $options{command_runner} ) {
-        $self->{command_runner} = $options{command_runner};
+    $self->{entity} = $factory->entities();
+    $self->{spec}   = $self->{entity}->get_entity($coordinate);
+
+    # Allow string, hashref with file key, or object
+    my $ref = ref( $self->{spec} );
+    if ($ref) {
+        if ( $ref eq 'HASH' ) {
+            if ( $self->{spec}{file} ) {
+                $self->{log_file} = $self->{spec}{file};
+            }
+            else {
+                invalid_entity( $coordinate, "must be file, or hashref with 'file' key" );
+            }
+        }
+        elsif ( $ref eq 'SCALAR' ) {
+            $self->{log_file} = $self->{spec};
+        }
+        else {
+            invalid_entity( $coordinate, "must be file, or hashref with 'file' key" );
+        }
     }
     else {
-        require Footprintless::CommandRunner::IPCRun;
-        $self->{command_runner} = Footprintless::CommandRunner::IPCRun->new();
+        $self->{log_file} = $self->{spec};
     }
-    $self->{localhost} = $options{localhost}
-        || Footprintless::Localhost->new()->load_all();
-    $self->{command_options_factory} = $options{command_options_factory}
-        || Footprintless::CommandOptionsFactory->new( localhost => $self->{localhost} );
 
-    $self->{command_options} = $self->{command_options_factory}->command_options(
-        %{  $entity->fill(
+    $self->{factory}         = $factory;
+    $self->{command_runner}  = $factory->command_runner();
+    $self->{command_options} = $factory->command_options(
+        %{  $self->{entity}->fill(
                 $coordinate,
                 {   hostname      => undef,
                     ssh           => undef,
@@ -168,15 +189,12 @@ sub _runner_options {
 
 sub tail {
     my ( $self, %options ) = @_;
-    my $log_file = $self->{spec};
 
-    my $action_options =
-        scalar( $options{options} )
-        ? join( ' ', @{ $options{options} }, '' )
-        : '';
+    my $action_args = _action_args( $options{args} );
 
     return $self->{command_runner}
-        ->run_or_die( command( "tail $action_options$log_file", $self->{command_options} ) );
+        ->run_or_die( command( "tail $action_args$self->{log_file}", $self->{command_options} ),
+        $self->_runner_options( $options{runner_options} ) );
 }
 
 1;
@@ -191,7 +209,7 @@ Footprintless::Log - A log manager
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 SYNOPSIS
 
@@ -211,12 +229,19 @@ Provides access to read from log files.
 
 =head1 ENTITIES
 
-A log entity is simply a name/value:
+A log entity can be a simple entity:
 
     catalina => '/opt/tomcat/logs/catalina.out'
 
-They will inherit all of their command options (C<hostname>, C<ssh>, 
-C<sudo_username>, C<username>)from their ancestry.  Logs are commonly 
+Or it can be a hashref entity containing, at minimum, a C<file> entity:
+
+    catalina => {
+        file => '/var/log/external/web/catalina.out',
+        hostname => 'loghost.pastdev.com'
+    }
+
+All unspecified command options will be inherited (C<hostname>, C<ssh>, 
+C<sudo_username>, C<username>) from their ancestry.  Logs are commonly 
 grouped together:
 
     web => {
@@ -224,6 +249,11 @@ grouped together:
         logs => {
             error => '/var/log/httpd/error_log',
             access => '/var/log/httpd/access_log'
+            catalina => {
+                file => '/opt/tomcat/logs/catalina.out',
+                hostname => 'app.pastdev.com',
+                sudo_username => 'tomcat'
+            }
         }
         sudo_username => 'apache'
     }
