@@ -2,10 +2,12 @@ use strict;
 use warnings;
 
 package Footprintless::Resource::Provider;
-$Footprintless::Resource::Provider::VERSION = '1.01';
+$Footprintless::Resource::Provider::VERSION = '1.02';
 # ABSTRACT: A contract for providing resources to the resource manager
 # PODNAME: Footprintless::Resource::Provider
 
+use Carp;
+
 sub new {
     return bless( {}, shift )->_init(@_);
 }
@@ -14,12 +16,10 @@ sub download {
     my ( $self, $resource, @options ) = @_;
 
     my $ref = ref($resource);
-    if ( !$resource->isa('Footprintless::Resource') ) {
-        if ($ref) {
-            croak("invalid resource [$ref]");
-        }
-        $resource = $self->resource($resource);
-    }
+    $resource = $self->resource($resource) if ( !$ref || $ref eq 'HASH' );
+
+    croak("invalid resource [$resource]")
+        unless ( $resource->isa('Footprintless::Resource') );
 
     return $self->_download( $resource, @options );
 }
@@ -56,7 +56,7 @@ Footprintless::Resource::Provider - A contract for providing resources to the re
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 DESCRIPTION
 
