@@ -2,12 +2,13 @@ use strict;
 use warnings;
 
 package Footprintless::Resource::UrlProvider;
-$Footprintless::Resource::UrlProvider::VERSION = '1.01';
+$Footprintless::Resource::UrlProvider::VERSION = '1.02';
 # ABSTRACT: A resource provider for resources retrieved by URL
 # PODNAME: Footprintless::Resource::UrlProvider
 
 use parent qw(Footprintless::Resource::Provider);
 
+use Carp;
 use File::Temp;
 use Footprintless::Resource::Url;
 use URI;
@@ -27,7 +28,9 @@ sub _download {
         $file = Footprintless::Resource::UrlProvider::DownloadedFile->new();
     }
 
-    $self->{agent}->get( $resource->get_uri(), ':content_file' => "$file" );
+    my $response = $self->{agent}->get( $resource->get_uri(), ':content_file' => "$file" );
+    croak( 'download failed: ', $response->message() )
+        unless ( $response->is_success() );
 
     return $file;
 }
@@ -57,7 +60,7 @@ sub supports {
 }
 
 package Footprintless::Resource::UrlProvider::DownloadedFile;
-$Footprintless::Resource::UrlProvider::DownloadedFile::VERSION = '1.01';
+$Footprintless::Resource::UrlProvider::DownloadedFile::VERSION = '1.02';
 # Wraps a temp file to hold a reference so as to keep the destructor from
 # getting called.  It will provide the filename when used as a string.
 
@@ -89,7 +92,7 @@ Footprintless::Resource::UrlProvider - A resource provider for resources retriev
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 CONSTRUCTORS
 
