@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Service;
-$Footprintless::Service::VERSION = '1.01';
+$Footprintless::Service::VERSION = '1.02';
 # ABSTRACT: Performs an action on a service.
 # PODNAME: Footprintless::Service
 
@@ -12,7 +12,11 @@ use Footprintless::Command qw(
     command
 );
 use Footprintless::CommandOptionsFactory;
+use Footprintless::InvalidEntityException;
 use Footprintless::Localhost;
+use Footprintless::Util qw(
+    invalid_entity
+);
 use Log::Any;
 
 my $logger = Log::Any->get_logger();
@@ -34,9 +38,13 @@ sub _command {
             return $actions_spec->{command};
         }
         elsif ( $actions_spec->{command_args} ) {
-            return "$command $actions_spec->{command_args}";
+            $action = $actions_spec->{command_args};
         }
         elsif ( $actions_spec->{use_pid} ) {
+            invalid_entity( $self->{coordinate},
+                "pid_file or pid_command required for [$action]" )
+                unless ( $self->{spec}{pid_file} || $self->{spec}{pid_command} );
+
             my $pid_file = $self->{spec}{pid_file};
             my $pid_command =
                 $pid_file
@@ -49,7 +57,7 @@ sub _command {
                 my $command_name = $actions_spec->{command_name} || $command || 'command';
                 return batch_command(
                     "pid=\$($pid_command)",
-                    "if \$(kill -0 \$pid 2> /dev/null)",
+                    "if [[ -n \$pid ]] && \$(kill -0 \$pid 2> /dev/null)",
                     "then printf '$command_name (pid \%s) is running...' \"\$pid\"",
                     "else printf '$command_name is stopped...'",
                     "fi",
@@ -57,46 +65,36 @@ sub _command {
                 );
             }
             else {
-                croak("use_pid not supported for $action");
+                invalid_entity( $self->{coordinate}, "use_pid not supported for [$action]" );
             }
         }
     }
+
+    invalid_entity( $self->{coordinate}, "no command specified for [$action]" )
+        unless ($command);
     return "$command $action";
 }
 
-sub _command_options {
-    my ($self) = @_;
-    return $self->{command_options_factory}->command_options( %{ $self->{spec} } );
-}
-
-sub _init {
-    my ( $self, $entity, $coordinate, %options ) = @_;
-    $logger->tracef( "entity=[%s]\ncoordinate=[%s]\noptions=[%s]",
-        $entity, $coordinate, \%options );
-
-    $self->{entity} = $entity;
-    $self->{spec}   = $entity->get_entity($coordinate);
-    if ( $options{command_runner} ) {
-        $self->{command_runner} = $options{command_runner};
-    }
-    else {
-        require Footprintless::CommandRunner::IPCRun;
-        $self->{command_runner} = Footprintless::CommandRunner::IPCRun->new();
-    }
-    $self->{localhost} = $options{localhost}
-        || Footprintless::Localhost->new()->load_all();
-    $self->{command_options_factory} = $options{command_options_factory}
-        || Footprintless::CommandOptionsFactory->new( localhost => $self->{localhost} );
-
-    return $self;
-}
-
 sub execute {
     my ( $self, $action ) = @_;
-    $self->{command_runner}->run_or_die(
-        command( $self->_command($action), $self->_command_options() ),
-        { out_handle => \*STDOUT, err_handle => \*STDERR }
-    );
+    $self->{command_runner}
+        ->run_or_die( command( $self->_command($action), $self->{command_options} ),
+        { out_handle => \*STDOUT } );
+}
+
+sub _init {
+    my ( $self, $factory, $coordinate, %options ) = @_;
+    $logger->tracef( "coordinate=[%s]\noptions=[%s]", $coordinate, \%options );
+
+    $self->{factory}    = $factory;
+    $self->{coordinate} = $coordinate;
+
+    $self->{entity}          = $factory->entities();
+    $self->{spec}            = $self->{entity}->get_entity($coordinate);
+    $self->{command_runner}  = $factory->command_runner();
+    $self->{command_options} = $factory->command_options( %{ $self->{spec} } );
+
+    return $self;
 }
 
 sub start {
@@ -123,7 +121,7 @@ Footprintless::Service - Performs an action on a service.
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 SYNOPSIS
 
